@@ -323,8 +323,13 @@ class BOJenkinsGenerateDatabaserInterfaceCommand(
         """
         Применение сгенерированного кода в Jenkins Job
         """
+        job_name = (
+            f'{self._bojenkins_config["jenkins"]["databaser_folder_name"].value}/'
+            f'{self._bojenkins_config["jenkins"]["databaser_job_name"].value}'
+        )
+
         config = jenkins_server.get_job_config(
-            self._bojenkins_config['jenkins']['databaser_job_name'].value
+            name=job_name,
         )
 
         config = ET.canonicalize(xml_data=config, strip_text=True)
@@ -348,14 +353,12 @@ class BOJenkinsGenerateDatabaserInterfaceCommand(
         prettified_xml = prettify_xml_element(root)
 
         jenkins_server.reconfig_job(
-            name=self._bojenkins_config['jenkins']['databaser_job_name'].value,
+            name=job_name,
             config_xml=prettified_xml,
         )
 
         logger.write(
-            f"Jenkins Job configuration "
-            f"{self._bojenkins_config['jenkins']['databaser_job_name'].value} "
-            f"updated."
+            f"Jenkins Job configuration {job_name} updated."
         )
 
     def take_action(
@@ -629,13 +632,18 @@ class BOJenkinsRunDatabaserCommand(
             password=self._bojenkins_config['jenkins']['password'].value,
         )
 
+        job_name = (
+            f'{self._bojenkins_config["jenkins"]["databaser_folder_name"].value}/'
+            f'{self._bojenkins_config["jenkins"]["databaser_job_name"].value}'
+        )
+
         job_info = self._jenkins_server.get_job_info(
-            name=self._bojenkins_config['jenkins']['databaser_job_name'].value,
+            name=job_name,
         )
 
         if (
-            not job_info['inQueue'] and
-            job_info['lastBuild']['number'] == job_info['lastCompletedBuild']['number']  # noqa
+            not job_info['inQueue']
+            and job_info['lastBuild']['number'] == job_info['lastCompletedBuild']['number']
         ):
             self._jira_client = JiraAPIClient(
                 url=self._bojira_config['jira']['url'].value,
@@ -714,7 +722,7 @@ class BOJenkinsRunDatabaserCommand(
                         }
 
                         self._jenkins_server.build_job(
-                            name=self._bojenkins_config['jenkins']['databaser_job_name'].value,  # noqa
+                            name=job_name,
                             parameters=parameters,
                         )
 
@@ -722,7 +730,7 @@ class BOJenkinsRunDatabaserCommand(
                         time.sleep(45)
 
                         updated_job_info = self._jenkins_server.get_job_info(
-                            name=self._bojenkins_config['jenkins']['databaser_job_name'].value,  # noqa
+                            name=job_name,
                         )
                         build_number = updated_job_info['lastBuild']['number']
 
@@ -733,9 +741,10 @@ class BOJenkinsRunDatabaserCommand(
                         )
 
                         build_url = (
-                            self._bojenkins_config['jenkins']['databaser_build_url_template'].value.format(  # noqa
-                                jenkins_url=self._bojenkins_config['jenkins']['url'].value,  # noqa
+                            self._bojenkins_config['jenkins']['databaser_build_url_template'].value.format(
+                                jenkins_url=self._bojenkins_config['jenkins']['url'].value,
                                 jenkins_databaser_job_name=self._bojenkins_config['jenkins']['databaser_job_name'].value,  # noqa
+                                jenkins_databaser_folder_name=self._bojenkins_config['jenkins']['databaser_folder_name'].value,  # noqa
                                 build_number=build_number,
                             )
                         )
@@ -935,7 +944,11 @@ class BOJenkinsCheckDatabaserCommand(
                 ),
             )
 
-        job_name = self._bojenkins_config['jenkins']['databaser_job_name'].value
+        job_name = (
+            f'{self._bojenkins_config["jenkins"]["databaser_folder_name"].value}/'
+            f'{self._bojenkins_config["jenkins"]["databaser_job_name"].value}'
+        )
+
         issues = self._parse_jira_issues_by_filter(
             jql_str=self._bojenkins_config['jenkins']['databaser_running_jira_filter'].value,
         )
