@@ -239,6 +239,7 @@ class ProjectPluginEnum(Enum):
     TAXNET_INTEGRATION = 'taxnet_integration'
     UDMURTIA_UFK = 'udmurtia_ufk'
     URM_KRISTA = 'urm_krista'
+    PERIOD_CLOSING_EXT = 'period_closing_ext'
 
     # Плигины ЗиК
     SALARY = 'salary'
@@ -477,6 +478,7 @@ class ProjectPluginEnum(Enum):
                     cls.SUPPLIER_PERSONALITIES,
                     cls.OPERATIONS_JOURNAL_04_ACCOUNTS_ANALYTICS,
                     cls.UDMURTIA_UFK,
+                    cls.PERIOD_CLOSING_EXT,
                 )
             )
 
@@ -643,6 +645,9 @@ class ProjectPluginEnum(Enum):
             cls.PAYMENT_SCHEDULE: (
                 cls.ACCOUNTING,
             ),
+            cls.PERIOD_CLOSING_EXT: (
+                cls.ACCOUNTING,
+            ),
             cls.PROPERTY_INTEGRATION: (
                 cls.ACCOUNTING,
             ),
